@@ -2,8 +2,15 @@ from typing import Union
 
 from gempy.core.data_modules.stack import Stack
 from gempy.core.data import Grid, Surfaces
-import xarray as xr
-import subsurface
+try:
+    import xarray as xr
+    import subsurface
+    from subsurface.structs.base_structures.common_data_utils import to_netcdf
+except:
+    print("Not subsurface compatibility available")
+
+
+
 import numpy as np
 import pandas as pd
 
@@ -78,7 +85,7 @@ class XSolution(object):
         simplex_array = np.concatenate(simplex)
         ids_array = np.concatenate(ids)
 
-        self.meshes = subsurface.UnstructuredData(
+        self.meshes = subsurface.UnstructuredData.from_array(
             vertex=vertex_array,
             cells=simplex_array,
             attributes=pd.DataFrame(ids_array, columns=['id'])
@@ -231,19 +238,19 @@ class XSolution(object):
             # Values and lith block
             property_v3 = xr.DataArray(
                 data=values[0][:, l0:l1],
-                dims=['attribute', 'cell'],
+                dims=['cell_attr', 'cell'],
             )
 
-            arrays['property_v3'] = property_v3
+            arrays['property'] = property_v3
 
         if values[1] is not None:
             # block
             block_v3 = xr.DataArray(
                 data=values[1][:, :, l0:l1],
-                dims=['Features', 'attribute', 'cell'],
+                dims=['Features', 'cell_attr', 'cell'],
             )
 
-            arrays['block_v3'] = block_v3
+            arrays['block'] = block_v3
 
         if values[4] is not None:
             # Scalar field
@@ -251,7 +258,7 @@ class XSolution(object):
                 data=values[4][:, l0:l1],
                 dims=['Features', 'cell'],
             )
-            arrays['scalar_field_v3'] = scalar_field_v3
+            arrays['scalar_field'] = scalar_field_v3
 
         if values[6] is not None:
             # Scalar field
@@ -259,7 +266,7 @@ class XSolution(object):
                 data=values[6][:, l0:l1],
                 dims=['Features', 'cell'],
             )
-            arrays['mask_v3'] = mask_v3
+            arrays['mask'] = mask_v3
 
         return arrays
 
@@ -269,10 +276,13 @@ class XSolution(object):
         coords = coords_base
         arrays = self.create_unstruct_xarray(values, l0, l1, xyz=None)
 
-        self.s_custom_grid = subsurface.UnstructuredData(
+        self.s_custom_grid = subsurface.UnstructuredData.from_array(
             vertex=xyz,
-            attributes=arrays,
-            coords=coords)
+            cells="points",
+            cells_attr=arrays,
+            coords=coords,
+            default_cells_attr_name="block"
+        )
 
         return self.s_custom_grid
 
@@ -284,7 +294,7 @@ class XSolution(object):
         arrays = self.create_struc_xarrays(values, l0, l1,
                                            self.grid.regular_grid.resolution)
 
-        self.s_regular_grid = subsurface.StructuredData(data=arrays, coords=coords)
+        self.s_regular_grid = subsurface.StructuredData.from_dict(data_dict=arrays, coords=coords)
 
     def add_cartesian_coords(self, coords_base):
         coords = coords_base
@@ -303,7 +313,7 @@ class XSolution(object):
         resolution = self.grid.topography.resolution
         arrays = self.create_struc_xarrays(values, l0, l1, resolution)
 
-        self.s_topography = subsurface.StructuredData(data=arrays, coords=coords)
+        self.s_topography = subsurface.StructuredData.from_dict(data_dict=arrays, coords=coords)
         return self.s_topography
 
     def set_values_to_sections(self,
@@ -321,21 +331,19 @@ class XSolution(object):
             coords['X'] = xy[:, 0]
             coords['Y'] = xy[:, 1]
 
-            arrays = self.create_struc_xarrays(values, l0 + l0_s, l0 + l1_s,
-                                               resolution)
+            arrays = self.create_struc_xarrays(values, l0 + l0_s, l0 + l1_s, resolution)
 
-            self.s_sections[name] = subsurface.StructuredData(data=arrays,
-                                                              coords=coords)
+            self.s_sections[name] = subsurface.StructuredData.from_dict(data_dict=arrays, coords=coords)
         return self.s_sections
 
     @property
     def data_structures(self):
         # TODO: Add sections
-        args = [self.s_regular_grid, self.s_custom_grid, self.s_topography,  self.meshes]
+        args = [self.s_regular_grid, self.s_custom_grid, self.s_topography, self.meshes]
         names = ['regular_grid', 'custom_grid', 'topography', 'meshes']
         return zip(args, names)
 
     def to_netcdf(self, path, name, **kwargs):
         for a, n in self.data_structures:
             if a is not None:
-                a.to_netcdf(f'{path}/{name}_{n}.nc', **kwargs)
+                to_netcdf(a, f'{path}/{name}_{n}.nc', **kwargs)
